##  Searching and Filtering Using Natural Language
If AI capabilities are enabled in your workspace, you can use natural language queries to filter and find fact sheets more easily. The system interprets your query and automatically applies the corresponding filters to narrow down the list of fact sheets.​
This makes it easier for all users, including those without in-depth SAP LeanIX knowledge, to search and apply filters quickly and intuitively.
To search and filter fact sheets using natural language, do the following:
  1. In the inventory, click Add Filter With AI.
  2. Enter your search/filter request in plain language (e.g., "Show me my apps").
  3. Click Apply to see the filtered results.


You can modify the generated filter manually or refine your natural language query for better results.
![Searching and Filtering Using Natural Language](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b8d7c7a4410149bebd060463bb2c3_LowRes.gif)
Searching and Filtering Using Natural Language
You can combine multiple conditions in a single query. For example: "<Show me applications that are used in Germany and store sensitive data objects.>" It also takes into account your custom attributes, provided you have configured them to be shown in filters.
Some example queries:
  * "Which data objects are sensitive?"​
  * "Which software is going out of life this year?"​
  * "Which software is out of life and still has active applications?"​
  * "Which applications has Frank Martin been responsible for?"​
  * "Which applications run on .NET technology?"​
  * "Which applications store sensitive data objects?"​
  * "Which applications are used in Germany or the US with functionality in HR Payroll?"​
